..  Copyright (C)  Stephen Schaub.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".



.. index:: web applications


Web Applications
----------------

In this chapter, you will learn how to create web applications in Python. There are two kinds of web
applications -- "client side" web applications and "server side" web applications. You've probably used
both kinds in your travels on the World-Wide Web.

* **Client-side** web applications are programs that are downloaded to a web browser and executed on
  the user's local machine. Client-side applications are typically written in JavaScript and embedded
  in web pages. 

* **Server-side** web applications are programs that run on web server computers, rather than on the
  user's local machine. Typically, a server-side web application displays a form with text boxes and
  other data collection mechanisms. The user fills out the form, clicks a submit button, and the
  browser sends the form to the web application on the server, which processes the request, and responds
  with another web page. If you've ever shopped online, you've used a server-side web application.

In this chapter, you will learn to build server-side web applications, which I will refer to simply as "web
applications."

